<template>
  <div id="create-signs">
    <h1>Create Shop Signs</h1>
    <p>Please choose the shop you would like to make a sign for:</p>
    <transition name="expand">
      <div v-show="notAvailable" class="errors">
        <p>This sign is currently being edited on another computer.</p>
      </div>
    </transition>
    <div id="shop-buttons">
      <template v-for="(shop, index) in shops">
        <a :key="index" class="button buildSign" @click="getSignAvailibility(shop.account)">{{shop.name}}</a>
      </template>
    </div>
    <h1>Create Personal Signs</h1>
    <ul class="errors"></ul>
      <label for="account-number">Account Number</label>
      <input v-model="personalAccountNumber" type="text" maxlength="3" name="personalAccount">
      <a class="button buildSign" @click="getSignAvailibility(parseInt(personalAccountNumber))">Create Personal Sign</a>
  </div>
</template>

<script>
export default {
  props: {
    shop: Object,
    shops: Array,
  },
  data(){
    return{
      personalAccountNumber:null,
      notAvailable:false
    }
  },
  methods:{
    getSignAvailibility(accountId) {
      app.api.Get( "/sign_and_print/getSignAvailibility/" + accountId)
        .then( Response => {
          console.log(Response);
          if(Response === 'new sign' || Response === false){
            app.$router.push({path: '/yat/sign_and_print/design', name:"sign_and_print_create_design",  params:{'accountId':accountId}});
          }
          else{
              setTimeout(() => {
              this.notAvailable = true;
            }, 5000);
          }
        })
        .catch( x => app.Message( x.error, "error" ) )
    }
  }
}
</script>

<style>

/* Errors */

/* always present */
.expand-transition {
  transition: all .3s ease;
  height: 30px;
  padding: 10px;
  background-color: #eee;
  overflow: hidden;
}
/* .expand-enter defines the starting state for entering */
/* .expand-leave defines the ending state for leaving */
.expand-enter, .expand-leave {
  height: 0;
  padding: 0 10px;
  opacity: 0;
}

div.errors {
    width: 85%;
    margin: 0 auto;
    list-style: none;
    font-family: "Mouse Memoirs";
    font-size: 24px;
    line-height: 1.1em;
    color: white;
}

div.errors p {
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    padding-left: 110px;
    padding-right: 20px;
    padding-bottom: 14px;
    background: rgba(255, 0, 0, .5);
    border-left: 3px solid red;
    border-right: 3px solid red;
    color: white !important;
    position: relative;
    text-indent: -8px;
}

div.errors p:before {
    content: "";
    display: block;
    position: relative;
    float: left;
    top: 9px;
    left: -17px;
    width: 8px;
    height: 8px;
    background: white;
    border-radius: 10px;
}

div.errors p:first-of-type {
    border-top-left-radius: 10px;
    border-top-right-radius: 10px;
    border-top: 3px solid red;
    background-image: url(/images/shop/shared/bg-error.png);
    background-position: 20px 10px;
    background-repeat: no-repeat;
    padding-top: 20px;
    margin-top: 30px;
}

div.errors p:last-of-type {
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
    border-bottom: 3px solid red;
    padding-bottom: 20px;
    margin-bottom: 10px;
}
</style>

